@@ -2,7 +2,7 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   Catfish - a versatile file searching tool
 #   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
-#   Copyright (C) 2012-2015 Sean Davis <smd.seandavis@gmail.com>
+#   Copyright (C) 2012-2016 Sean Davis <smd.seandavis@gmail.com>
 #
 #   This program is free software: you can redistribute it and/or modify it
 #   under the terms of the GNU General Public License version 2, as published
@@ -34,19 +34,24 @@ def check_gtk_version(major_version, minor_version, micro=0):
 
 # Check if the LANG variable needs to be set
 use_env = False
+use_pkexec = False
 
 
 def check_dependencies(commands=[]):
     """Check for the existence of required commands, and sudo access"""
-    # Check for sudo
-    if pexpect.which("sudo") is None:
-        return False
-
     # Check for required commands
     for command in commands:
         if pexpect.which(command) is None:
             return False
 
+    # Check for sudo or pkexec
+    if pexpect.which("pkexec") is not None:
+        use_pkexec = True
+        return True
+
+    if pexpect.which("sudo") is None:
+        return False
+
     # Check for LANG requirements
     child = env_spawn('sudo -v', 1)
     if child.expect([".*ssword.*", "Sorry",
@@ -86,6 +91,18 @@ def env_spawn(command, timeout):
     return child
 
 
+def passwordless_sudo():
+    """Return true if no password required to use sudo."""
+    p = env_spawn("sudo -n true", 2)
+    p.expect(pexpect.EOF)
+    p.close()
+    return p.exitstatus == 0
+
+
+def prefer_pkexec():
+    return prefer_pkexec
+
+
 class SudoDialog(Gtk.Dialog):
 
     '''
@@ -211,8 +228,6 @@ class SudoDialog(Gtk.Dialog):
         self.attempted_logins = 0
         self.max_attempted_logins = retries
 
-        self.show_all()
-
     def on_password_changed(self, widget, button):
         """Set the apply button sensitivity based on password input."""
         button.set_sensitive(len(widget.get_text()) > 0)
